@@ -13,9 +13,9 @@ from .run import (
     DbtCloudRunListCommand,
     DbtCloudRunCancelCommand,
 )
-from .project import DbtCloudProjectListCommand
+from .project import DbtCloudProjectListCommand, DbtCloudProjectGetCommand
 from .environment import DbtCloudEnvironmentListCommand
-from .account import DbtCloudAccountListCommand
+from .account import DbtCloudAccountListCommand, DbtCloudAccountGetCommand
 from .audit_log import DbtCloudAuditLogGetCommand
 from .metadata import DbtCloudMetadataQueryCommand
 from .command import DbtCloudAccountCommand
