@@ -7,6 +7,7 @@ from dbt_cloud.command import (
     DbtCloudJobGetCommand,
     DbtCloudJobListCommand,
     DbtCloudJobRunCommand,
+    DbtCloudProjectGetCommand,
     DbtCloudProjectListCommand,
     DbtCloudRunCancelCommand,
     DbtCloudRunGetArtifactCommand,
@@ -15,6 +16,7 @@ from dbt_cloud.command import (
     DbtCloudRunListCommand,
     DbtCloudEnvironmentListCommand,
     DbtCloudAccountListCommand,
+    DbtCloudAccountGetCommand,
     DbtCloudAuditLogGetCommand,
 )
 
@@ -133,7 +135,16 @@ COMMAND_TEST_CASES = [
         marks=pytest.mark.run,
     ),
     pytest.param(
-        "project_list_artifact",
+        "project_get",
+        DbtCloudProjectGetCommand(
+            api_token=API_TOKEN, account_id=ACCOUNT_ID, project_id=PROJECT_ID
+        ),
+        load_response("project_get_response"),
+        "get",
+        marks=pytest.mark.project,
+    ),
+    pytest.param(
+        "project_list",
         DbtCloudProjectListCommand(api_token=API_TOKEN, account_id=ACCOUNT_ID),
         load_response("project_list_response"),
         "get",
@@ -155,6 +166,13 @@ COMMAND_TEST_CASES = [
         "get",
         marks=pytest.mark.account,
     ),
+    pytest.param(
+        "account_get",
+        DbtCloudAccountGetCommand(api_token=API_TOKEN),
+        load_response("account_get_response"),
+        "get",
+        marks=pytest.mark.account,
+    ),
     pytest.param(
         "audit_log_get",
         DbtCloudAuditLogGetCommand(
